@@ -21,7 +21,7 @@ class Notification(models.Model):
     )
 
     has_read = models.BooleanField(verbose_name=_('Read Or Not'), default=False)
-    push_state = models.PositiveIntegerField(max_length=16, choices=PUSH_STATE_CHOICE, default=READY)
+    push_state = models.PositiveIntegerField(choices=PUSH_STATE_CHOICE, default=READY)
     to = models.ManyToManyField(settings.AUTH_USER_MODEL, verbose_name=_('Receivers'))
     etag = models.TextField(verbose_name=_('Etag'), null=True, blank=True)
     content_type = models.ForeignKey(
